# Whitebox Plugin - Flight Management

This is a plugin for [whitebox](https://gitlab.com/whitebox-aero) that allows management of devices connected to Whitebox.

## Installation

Install the plugin to whitebox:

```
poetry add whitebox-plugin-flight-management
```

## Additional Instructions

- [Plugin Development Guide](https://docs.whitebox.aero/plugin_guide/#plugin-development-workflow)
- [Plugin Testing Guide](https://docs.whitebox.aero/plugin_guide/#testing-plugins)
- [Contributing Guidelines](https://docs.whitebox.aero/development_guide/#contributing)
